#ifndef KYSEC_DB_H
#define KYSEC_DB_H

#include <sqlite3.h>

#ifndef uint_64
#define uint_64 unsigned long long
#endif // !uint_64

#ifdef __cplusplus
extern "C" {
#endif

typedef enum kysec_sqlite_perm
{
    kysec_sqlite_r = 0,
    kysec_sqlite_rw
}kysec_sqlite_perm;

typedef int (*retrieve_callback)(void *context,int sum_row_count, int col_count, char **column_string,int row_index);

int get_last_err_code(sqlite3 *sqlite);
const char *get_last_err_msg(sqlite3 *sqlite);
const char *get_sqlite_err_msg(int err_code);

//数据库联接，返回0为正功，其它均为失败；
int connect_sqlite(char *db_path, sqlite3 **sqlite);
int connect_sqlite_with_perm(char *db_path, sqlite3 **sqlite, kysec_sqlite_perm perm);
int disconnect_sqlite(sqlite3 *sqlite);

//事务操作接口，返回0为正功，其它均为失败；
int sqlite_begin(sqlite3 *sqlite);
int sqlite_begin_immediate(sqlite3 *sqlite);
int sqlite_begin_exclusive(sqlite3 *sqlite);
int sqlite_commit(sqlite3 *sqlite);
int sqlite_rollback(sqlite3 *sqlite);

//数据库操作（查询），返回0为正功，其它均为失败；
int sqlite_retrieve(sqlite3 *sqlite, const char *sql,retrieve_callback func,void * context);
int sqlite_retrieve_whitout_transaction(sqlite3 *sqlite, const char *sql,retrieve_callback func,void * context);
int sqlite_update(sqlite3 *sqlite, const char *sql);
int sqlite_insert(sqlite3 *sqlite, const char *sql);
int sqlite_delete(sqlite3 *sqlite, const char *sql);
int sqlite_exec_sql(sqlite3 *sqlite, const char *sql);
uint_64 sqlite_get_auto_increment_ID(sqlite3 *sqlite);

int sqlite_prepare_stmt(sqlite3 *sqlite, const char *sql, sqlite3_stmt **stmt);
int sqlite_bind_int_stmt(sqlite3_stmt* stmt, int index, int value);
int sqlite_bind_text_stmt(sqlite3_stmt* stmt,int index,const char* value);
int sqlite_column_int_stmt(sqlite3_stmt*, int column);
const unsigned char *sqlite_column_text_stmt(sqlite3_stmt*, int column);
int sqlite_reset_stmt(sqlite3_stmt *stmt);
int sqlite_step_stmt(sqlite3_stmt *stmt);
int sqlite_finalize_stmt(sqlite3_stmt *stmt);


#ifdef __cplusplus
}
#endif

#endif /* KYSEC_DB_H */
