#ifndef KYSEC_FDIR_H
#define KYSEC_FDIR_H

#include <stdlib.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * 获取文件或目录的绝对路径
 */
extern char *get_absolute_path(const char *path);

/**
 * 判断路径是否存在，存在返回1，不存在或出错返回-1
 */
extern int path_is_exist(const char *path);

/**
 * 判断路径是否为目录
 */
extern int path_is_dir(const char *path);

/**
 * 判断路径是否为软连接
 */
extern int path_is_link(const char *path);

/**
 * 判断两个路径对应的文件是否是同一个文件
 */
extern int path_is_same(const char *path1, const char *path2);

/*
 * 判断两个挂载点是否为bind挂载
 */
extern int path_is_mount_bind(char *mnt_point1, char *mnt_point2);

/**
 * 获取目录下所有文件列表
 */
extern char **get_file_list_from_dir(const char *dir, int *count);

/**
 * 删除目录及目录下文件
 */
extern int remove_dir(const char *dir);

/**
 * 拷贝文件，若dest_file存在，则先删除，再创建
 * 注意： 改功能仅支持普通文件拷贝操作
 */
extern int copy_file(const char *src_file, const char *dest_file);

/**
 * 拷贝目录至目标目录下
 */
extern int copy_dir(const char *src_dir, const char *dest_dir);

#ifdef __cplusplus
}
#endif

#endif /* KYSEC_FDIR_H */
